# Lolzteam_Python_Api
Обычная либа для зеленки
Есть несколько твиков (костыли), которые фиксят некоторые неприятные моменты из темы ниже

https://zelenka.guru/threads/5447086/ Гриша нужно чинить

В течение пары дней добавлю сюда маркет, сейчас воркает только форумная часть

Пример использования либы находится [здесь](Examples/example.py)

Пример использования либы маркета находится [здесь](Examples/example_market.py)
